@@ -1,33 +1,20 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 // Qt
-#include <QtTest>
+#include <QSignalSpy>
+#include <QTest>
 // KWin
 #include "../../src/client/compositor.h"
 #include "../../src/client/connection_thread.h"
 #include "../../src/client/event_queue.h"
 #include "../../src/client/pointer.h"
+#include "../../src/client/registry.h"
 #include "../../src/client/seat.h"
 #include "../../src/client/shell.h"
 #include "../../src/client/surface.h"
-#include "../../src/client/registry.h"
 #include "../../src/server/buffer_interface.h"
 #include "../../src/server/compositor_interface.h"
 #include "../../src/server/display.h"
@@ -132,7 +119,7 @@ void TestWaylandShell::init()
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
-    QSignalSpy connectedSpy(m_connection, SIGNAL(connected()));
+    QSignalSpy connectedSpy(m_connection, &KWayland::Client::ConnectionThread::connected);
     m_connection->setSocketName(s_socketName);
 
     m_thread = new QThread(this);
@@ -151,8 +138,8 @@ void TestWaylandShell::init()
     KWayland::Client::Registry registry;
     QSignalSpy interfacesAnnouncedSpy(&registry, &Registry::interfacesAnnounced);
     QVERIFY(interfacesAnnouncedSpy.isValid());
-    QSignalSpy compositorSpy(&registry, SIGNAL(compositorAnnounced(quint32,quint32)));
-    QSignalSpy shellSpy(&registry, SIGNAL(shellAnnounced(quint32,quint32)));
+    QSignalSpy compositorSpy(&registry, &KWayland::Client::Registry::compositorAnnounced);
+    QSignalSpy shellSpy(&registry, &KWayland::Client::Registry::shellAnnounced);
     QSignalSpy seatAnnouncedSpy(&registry, &Registry::seatAnnounced);
     QVERIFY(seatAnnouncedSpy.isValid());
     QVERIFY(!registry.eventQueue());
@@ -242,7 +229,7 @@ void TestWaylandShell::testCreateMultiple()
     QVERIFY(!s2.isNull());
     QVERIFY(s2->isValid());
 
-    QSignalSpy serverSurfaceSpy(m_shellInterface, SIGNAL(surfaceCreated(KWayland::Server::ShellSurfaceInterface*)));
+    QSignalSpy serverSurfaceSpy(m_shellInterface, &KWayland::Server::ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QScopedPointer<ShellSurface> surface1(m_shell->createSurface(s1.data()));
     QVERIFY(!surface1.isNull());
@@ -278,19 +265,19 @@ void TestWaylandShell::testFullscreen()
     QVERIFY(!s.isNull());
     QVERIFY(s->isValid());
     KWayland::Client::ShellSurface *surface = m_shell->createSurface(s.data(), m_shell);
-    QSignalSpy sizeSpy(surface, SIGNAL(sizeChanged(QSize)));
+    QSignalSpy sizeSpy(surface, &KWayland::Client::ShellSurface::sizeChanged);
     QVERIFY(sizeSpy.isValid());
     QCOMPARE(surface->size(), QSize());
 
-    QSignalSpy serverSurfaceSpy(m_shellInterface, SIGNAL(surfaceCreated(KWayland::Server::ShellSurfaceInterface*)));
+    QSignalSpy serverSurfaceSpy(m_shellInterface, &KWayland::Server::ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
     QVERIFY(serverSurface->parentResource());
     QCOMPARE(serverSurface->shell(), m_shellInterface);
 
-    QSignalSpy fullscreenSpy(serverSurface, SIGNAL(fullscreenChanged(bool)));
+    QSignalSpy fullscreenSpy(serverSurface, &ShellSurfaceInterface::fullscreenChanged);
     QVERIFY(fullscreenSpy.isValid());
 
     QVERIFY(!serverSurface->isFullscreen());
@@ -322,18 +309,18 @@ void TestWaylandShell::testMaximize()
     QVERIFY(!s.isNull());
     QVERIFY(s->isValid());
     KWayland::Client::ShellSurface *surface = m_shell->createSurface(s.data(), m_shell);
-    QSignalSpy sizeSpy(surface, SIGNAL(sizeChanged(QSize)));
+    QSignalSpy sizeSpy(surface, &KWayland::Client::ShellSurface::sizeChanged);
     QVERIFY(sizeSpy.isValid());
     QCOMPARE(surface->size(), QSize());
 
-    QSignalSpy serverSurfaceSpy(m_shellInterface, SIGNAL(surfaceCreated(KWayland::Server::ShellSurfaceInterface*)));
+    QSignalSpy serverSurfaceSpy(m_shellInterface, &KWayland::Server::ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
     QVERIFY(serverSurface->parentResource());
 
-    QSignalSpy maximizedSpy(serverSurface, SIGNAL(maximizedChanged(bool)));
+    QSignalSpy maximizedSpy(serverSurface, &ShellSurfaceInterface::maximizedChanged);
     QVERIFY(maximizedSpy.isValid());
 
     QVERIFY(!serverSurface->isMaximized());
@@ -365,18 +352,18 @@ void TestWaylandShell::testToplevel()
     QVERIFY(!s.isNull());
     QVERIFY(s->isValid());
     KWayland::Client::ShellSurface *surface = m_shell->createSurface(s.data(), m_shell);
-    QSignalSpy sizeSpy(surface, SIGNAL(sizeChanged(QSize)));
+    QSignalSpy sizeSpy(surface, &KWayland::Client::ShellSurface::sizeChanged);
     QVERIFY(sizeSpy.isValid());
     QCOMPARE(surface->size(), QSize());
 
-    QSignalSpy serverSurfaceSpy(m_shellInterface, SIGNAL(surfaceCreated(KWayland::Server::ShellSurfaceInterface*)));
+    QSignalSpy serverSurfaceSpy(m_shellInterface, &KWayland::Server::ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
     QVERIFY(serverSurface->parentResource());
 
-    QSignalSpy toplevelSpy(serverSurface, SIGNAL(toplevelChanged(bool)));
+    QSignalSpy toplevelSpy(serverSurface, &ShellSurfaceInterface::toplevelChanged);
     QVERIFY(toplevelSpy.isValid());
 
     surface->setFullscreen();
@@ -423,7 +410,7 @@ void TestWaylandShell::testTransient()
     QSignalSpy serverSurfaceSpy(m_shellInterface, &ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
     QSignalSpy acceptsKeyboardFocusChangedSpy(serverSurface, &ShellSurfaceInterface::acceptsKeyboardFocusChanged);
     QVERIFY(acceptsKeyboardFocusChangedSpy.isValid());
@@ -446,7 +433,7 @@ void TestWaylandShell::testTransient()
     m_shell->createSurface(s2.data(), m_shell);
     serverSurfaceSpy.clear();
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface2 = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface2 = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface2 != serverSurface);
     QVERIFY(serverSurface2);
     QVERIFY(serverSurface2->acceptsKeyboardFocus());
@@ -488,7 +475,7 @@ void TestWaylandShell::testTransientPopup()
     QSignalSpy serverSurfaceSpy(m_shellInterface, &ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
     QCOMPARE(serverSurface->isToplevel(), true);
     QCOMPARE(serverSurface->isPopup(), false);
@@ -508,7 +495,7 @@ void TestWaylandShell::testTransientPopup()
     m_shell->createSurface(s2.data(), m_shell);
     serverSurfaceSpy.clear();
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface2 = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface2 = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface2 != serverSurface);
     QVERIFY(serverSurface2);
     QVERIFY(serverSurface2->acceptsKeyboardFocus());
@@ -549,18 +536,18 @@ void TestWaylandShell::testPing()
     QVERIFY(!s.isNull());
     QVERIFY(s->isValid());
     KWayland::Client::ShellSurface *surface = m_shell->createSurface(s.data(), m_shell);
-    QSignalSpy pingSpy(surface, SIGNAL(pinged()));
+    QSignalSpy pingSpy(surface, &KWayland::Client::ShellSurface::pinged);
 
-    QSignalSpy serverSurfaceSpy(m_shellInterface, SIGNAL(surfaceCreated(KWayland::Server::ShellSurfaceInterface*)));
+    QSignalSpy serverSurfaceSpy(m_shellInterface, &KWayland::Server::ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
     QVERIFY(!serverSurface->isPinged());
 
-    QSignalSpy pingTimeoutSpy(serverSurface, SIGNAL(pingTimeout()));
+    QSignalSpy pingTimeoutSpy(serverSurface, &ShellSurfaceInterface::pingTimeout);
     QVERIFY(pingTimeoutSpy.isValid());
-    QSignalSpy pongSpy(serverSurface, SIGNAL(pongReceived()));
+    QSignalSpy pongSpy(serverSurface, &ShellSurfaceInterface::pongReceived);
     QVERIFY(pongSpy.isValid());
 
     serverSurface->ping();
@@ -595,13 +582,13 @@ void TestWaylandShell::testTitle()
     QVERIFY(s->isValid());
     KWayland::Client::ShellSurface *surface = m_shell->createSurface(s.data(), m_shell);
 
-    QSignalSpy serverSurfaceSpy(m_shellInterface, SIGNAL(surfaceCreated(KWayland::Server::ShellSurfaceInterface*)));
+    QSignalSpy serverSurfaceSpy(m_shellInterface, &KWayland::Server::ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
 
-    QSignalSpy titleSpy(serverSurface, SIGNAL(titleChanged(QString)));
+    QSignalSpy titleSpy(serverSurface, &ShellSurfaceInterface::titleChanged);
     QVERIFY(titleSpy.isValid());
     QString testTitle = QStringLiteral("fooBar");
     QVERIFY(serverSurface->title().isNull());
@@ -620,13 +607,13 @@ void TestWaylandShell::testWindowClass()
     QVERIFY(s->isValid());
     KWayland::Client::ShellSurface *surface = m_shell->createSurface(s.data(), m_shell);
 
-    QSignalSpy serverSurfaceSpy(m_shellInterface, SIGNAL(surfaceCreated(KWayland::Server::ShellSurfaceInterface*)));
+    QSignalSpy serverSurfaceSpy(m_shellInterface, &KWayland::Server::ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
 
-    QSignalSpy windowClassSpy(serverSurface, SIGNAL(windowClassChanged(QByteArray)));
+    QSignalSpy windowClassSpy(serverSurface, &ShellSurfaceInterface::windowClassChanged);
     QVERIFY(windowClassSpy.isValid());
     QByteArray testClass = QByteArrayLiteral("fooBar");
     QVERIFY(serverSurface->windowClass().isNull());
@@ -657,7 +644,7 @@ void TestWaylandShell::testDestroy()
     connect(m_connection, &ConnectionThread::connectionDied, s.data(), &Surface::destroy);
     connect(m_connection, &ConnectionThread::connectionDied, m_queue, &EventQueue::destroy);
 
-    QSignalSpy connectionDiedSpy(m_connection, SIGNAL(connectionDied()));
+    QSignalSpy connectionDiedSpy(m_connection, &KWayland::Client::ConnectionThread::connectionDied);
     QVERIFY(connectionDiedSpy.isValid());
     delete m_display;
     m_display = nullptr;
@@ -677,7 +664,7 @@ void TestWaylandShell::testCast()
 {
     using namespace KWayland::Client;
     Registry registry;
-    QSignalSpy shellSpy(&registry, SIGNAL(shellAnnounced(quint32,quint32)));
+    QSignalSpy shellSpy(&registry, &KWayland::Client::Registry::shellAnnounced);
     registry.setEventQueue(m_queue);
     registry.create(m_connection->display());
     QVERIFY(registry.isValid());
@@ -691,10 +678,10 @@ void TestWaylandShell::testCast()
     QVERIFY(!s.isValid());
     s.setup(wlShell);
     QVERIFY(s.isValid());
-    QCOMPARE((wl_shell*)s, wlShell);
+    QCOMPARE((wl_shell *)s, wlShell);
 
     const Shell &s2(s);
-    QCOMPARE((wl_shell*)s2, wlShell);
+    QCOMPARE((wl_shell *)s2, wlShell);
 }
 
 void TestWaylandShell::testMove()
@@ -709,7 +696,7 @@ void TestWaylandShell::testMove()
     QSignalSpy serverSurfaceSpy(m_shellInterface, &ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
     QSignalSpy moveRequestedSpy(serverSurface, &ShellSurfaceInterface::moveRequested);
     QVERIFY(moveRequestedSpy.isValid());
@@ -724,7 +711,7 @@ void TestWaylandShell::testMove()
     surface->requestMove(m_seat, pointerButtonChangedSpy.first().first().value<quint32>());
     QVERIFY(moveRequestedSpy.wait());
     QCOMPARE(moveRequestedSpy.count(), 1);
-    QCOMPARE(moveRequestedSpy.first().at(0).value<SeatInterface*>(), m_seatInterface);
+    QCOMPARE(moveRequestedSpy.first().at(0).value<SeatInterface *>(), m_seatInterface);
     QCOMPARE(moveRequestedSpy.first().at(1).value<quint32>(), m_seatInterface->pointerButtonSerial(Qt::LeftButton));
 }
 
@@ -735,22 +722,22 @@ void TestWaylandShell::testResize_data()
 
     QTest::newRow("None") << Qt::Edges() << Qt::Edges();
 
-    QTest::newRow("Top")    << Qt::Edges(Qt::TopEdge)    << Qt::Edges(Qt::TopEdge);
+    QTest::newRow("Top") << Qt::Edges(Qt::TopEdge) << Qt::Edges(Qt::TopEdge);
     QTest::newRow("Bottom") << Qt::Edges(Qt::BottomEdge) << Qt::Edges(Qt::BottomEdge);
-    QTest::newRow("Left")   << Qt::Edges(Qt::LeftEdge)   << Qt::Edges(Qt::LeftEdge);
-    QTest::newRow("Right")  << Qt::Edges(Qt::RightEdge)  << Qt::Edges(Qt::RightEdge);
+    QTest::newRow("Left") << Qt::Edges(Qt::LeftEdge) << Qt::Edges(Qt::LeftEdge);
+    QTest::newRow("Right") << Qt::Edges(Qt::RightEdge) << Qt::Edges(Qt::RightEdge);
 
-    QTest::newRow("Top Left")     << Qt::Edges(Qt::TopEdge | Qt::LeftEdge)     << Qt::Edges(Qt::TopEdge | Qt::LeftEdge);
-    QTest::newRow("Top Right")    << Qt::Edges(Qt::TopEdge | Qt::RightEdge)    << Qt::Edges(Qt::TopEdge | Qt::RightEdge);
-    QTest::newRow("Bottom Left")  << Qt::Edges(Qt::BottomEdge | Qt::LeftEdge)  << Qt::Edges(Qt::BottomEdge | Qt::LeftEdge);
+    QTest::newRow("Top Left") << Qt::Edges(Qt::TopEdge | Qt::LeftEdge) << Qt::Edges(Qt::TopEdge | Qt::LeftEdge);
+    QTest::newRow("Top Right") << Qt::Edges(Qt::TopEdge | Qt::RightEdge) << Qt::Edges(Qt::TopEdge | Qt::RightEdge);
+    QTest::newRow("Bottom Left") << Qt::Edges(Qt::BottomEdge | Qt::LeftEdge) << Qt::Edges(Qt::BottomEdge | Qt::LeftEdge);
     QTest::newRow("Bottom Right") << Qt::Edges(Qt::BottomEdge | Qt::RightEdge) << Qt::Edges(Qt::BottomEdge | Qt::RightEdge);
 
     // invalid combinations
     QTest::newRow("Top Bottom") << Qt::Edges(Qt::TopEdge | Qt::BottomEdge) << Qt::Edges();
     QTest::newRow("Left Right") << Qt::Edges(Qt::RightEdge | Qt::LeftEdge) << Qt::Edges();
-    QTest::newRow("Top Bottom Right")  << Qt::Edges(Qt::TopEdge | Qt::BottomEdge | Qt::RightEdge)  << Qt::Edges();
-    QTest::newRow("Top Bottom Left")   << Qt::Edges(Qt::TopEdge | Qt::BottomEdge | Qt::LeftEdge)   << Qt::Edges();
-    QTest::newRow("Left Right Top")    << Qt::Edges(Qt::RightEdge | Qt::LeftEdge | Qt::TopEdge)    << Qt::Edges();
+    QTest::newRow("Top Bottom Right") << Qt::Edges(Qt::TopEdge | Qt::BottomEdge | Qt::RightEdge) << Qt::Edges();
+    QTest::newRow("Top Bottom Left") << Qt::Edges(Qt::TopEdge | Qt::BottomEdge | Qt::LeftEdge) << Qt::Edges();
+    QTest::newRow("Left Right Top") << Qt::Edges(Qt::RightEdge | Qt::LeftEdge | Qt::TopEdge) << Qt::Edges();
     QTest::newRow("Left Right Bottom") << Qt::Edges(Qt::RightEdge | Qt::LeftEdge | Qt::BottomEdge) << Qt::Edges();
     QTest::newRow("All") << Qt::Edges(Qt::RightEdge | Qt::LeftEdge | Qt::BottomEdge | Qt::TopEdge) << Qt::Edges();
 }
@@ -767,7 +754,7 @@ void TestWaylandShell::testResize()
     QSignalSpy serverSurfaceSpy(m_shellInterface, &ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
     QSignalSpy resizeRequestedSpy(serverSurface, &ShellSurfaceInterface::resizeRequested);
     QVERIFY(resizeRequestedSpy.isValid());
@@ -783,7 +770,7 @@ void TestWaylandShell::testResize()
     surface->requestResize(m_seat, pointerButtonChangedSpy.first().first().value<quint32>(), resizeEdge);
     QVERIFY(resizeRequestedSpy.wait());
     QCOMPARE(resizeRequestedSpy.count(), 1);
-    QCOMPARE(resizeRequestedSpy.first().at(0).value<SeatInterface*>(), m_seatInterface);
+    QCOMPARE(resizeRequestedSpy.first().at(0).value<SeatInterface *>(), m_seatInterface);
     QCOMPARE(resizeRequestedSpy.first().at(1).value<quint32>(), m_seatInterface->pointerButtonSerial(Qt::LeftButton));
     QTEST(resizeRequestedSpy.first().at(2).value<Qt::Edges>(), "expectedEdge");
 }
@@ -800,7 +787,7 @@ void TestWaylandShell::testDisconnect()
     QSignalSpy serverSurfaceSpy(m_shellInterface, &ShellInterface::surfaceCreated);
     QVERIFY(serverSurfaceSpy.isValid());
     QVERIFY(serverSurfaceSpy.wait());
-    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface*>();
+    ShellSurfaceInterface *serverSurface = serverSurfaceSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverSurface);
 
     // destroy client
@@ -843,7 +830,7 @@ void TestWaylandShell::testWhileDestroying()
     QVERIFY(surfaceCreatedSpy.isValid());
     QScopedPointer<Surface> s(m_compositor->createSurface());
     QVERIFY(surfaceCreatedSpy.wait());
-    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface*>();
+    auto serverSurface = surfaceCreatedSpy.first().first().value<SurfaceInterface *>();
     QVERIFY(serverSurface);
 
     // create ShellSurface
@@ -880,7 +867,7 @@ void TestWaylandShell::testClientDisconnecting()
     QScopedPointer<ShellSurface> ps(m_shell->createSurface(s.data()));
     QVERIFY(shellSurfaceCreatedSpy.wait());
 
-    auto serverShellSurface = shellSurfaceCreatedSpy.first().first().value<ShellSurfaceInterface*>();
+    auto serverShellSurface = shellSurfaceCreatedSpy.first().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverShellSurface);
 
     QSignalSpy shellSurfaceUnboundSpy(serverShellSurface, &Resource::unbound);
@@ -889,14 +876,12 @@ void TestWaylandShell::testClientDisconnecting()
     QScopedPointer<Surface> s2(m_compositor->createSurface());
     QScopedPointer<ShellSurface> ps2(m_shell->createSurface(s2.data()));
     QVERIFY(shellSurfaceCreatedSpy.wait());
-    auto serverShellSurface2 = shellSurfaceCreatedSpy.last().first().value<ShellSurfaceInterface*>();
+    auto serverShellSurface2 = shellSurfaceCreatedSpy.last().first().value<ShellSurfaceInterface *>();
     QVERIFY(serverShellSurface2);
 
-    connect(serverShellSurface, &Resource::unbound, this,
-        [serverShellSurface, serverShellSurface2] {
-            serverShellSurface2->requestSize(QSize(100, 200));
-        }
-    );
+    connect(serverShellSurface, &Resource::unbound, this, [serverShellSurface2] {
+        serverShellSurface2->requestSize(QSize(100, 200));
+    });
 
     m_connection->deleteLater();
     m_connection = nullptr;
