@@ -17,7 +17,6 @@ namespace KWayland
 namespace Server
 {
 class DataDeviceManagerInterface;
-class DataOfferInterface;
 class DataSourceInterface;
 class SeatInterface;
 class SurfaceInterface;
@@ -37,7 +36,7 @@ class KWAYLANDSERVER_EXPORT DataDeviceInterface : public Resource
 {
     Q_OBJECT
 public:
-    virtual ~DataDeviceInterface();
+    ~DataDeviceInterface() override;
 
     SeatInterface *seat() const;
     DataSourceInterface *dragSource() const;
