@@ -1,29 +1,15 @@
-/****************************************************************************
-Copyright 2016  Oleg Chernovskiy <kanedias@xaker.ru>
+/*
+    SPDX-FileCopyrightText: 2016 Oleg Chernovskiy <kanedias@xaker.ru>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-****************************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "remote_access_interface.h"
-#include "remote_access_interface_p.h"
-#include "output_interface.h"
 #include "display.h"
 #include "global_p.h"
-#include "resource_p.h"
 #include "logging.h"
+#include "output_interface.h"
+#include "remote_access_interface_p.h"
+#include "resource_p.h"
 
 #include <wayland-remote-access-server-protocol.h>
 
@@ -36,7 +22,6 @@ namespace KWayland
 {
 namespace Server
 {
-
 class BufferHandle::Private // @see gbm_import_fd_data
 {
 public:
@@ -90,7 +75,6 @@ void BufferHandle::setStride(quint32 stride)
     d->stride = stride;
 }
 
-
 quint32 BufferHandle::stride() const
 {
     return d->stride;
@@ -110,12 +94,11 @@ quint32 BufferHandle::format() const
  * @brief helper struct for manual reference counting.
  * automatic counting via QSharedPointer is no-go here as we hold strong reference in sentBuffers.
  */
-struct BufferHolder
-{
+struct BufferHolder {
     const BufferHandle *buf;
     quint64 counter;
 };
-    
+
 class RemoteAccessManagerInterface::Private : public Global::Private
 {
 public:
@@ -140,11 +123,13 @@ public:
      * remote control app etc.
      */
     QList<wl_resource *> clientResources;
+
 private:
     // methods
     static void unbind(wl_resource *resource);
-    static Private *cast(wl_resource *r) {
-        return reinterpret_cast<Private*>(wl_resource_get_user_data(r));
+    static Private *cast(wl_resource *r)
+    {
+        return reinterpret_cast<Private *>(wl_resource_get_user_data(r));
     }
     static void getBufferCallback(wl_client *client, wl_resource *resource, uint32_t buffer, int32_t internalBufId);
     static void releaseCallback(wl_client *client, wl_resource *resource);
@@ -195,7 +180,7 @@ void RemoteAccessManagerInterface::Private::bind(wl_client *client, uint32_t ver
 
 void RemoteAccessManagerInterface::Private::sendBufferReady(const OutputInterface *output, const BufferHandle *buf)
 {
-    BufferHolder holder {buf, 0};
+    BufferHolder holder{buf, 0};
     // notify clients
     qCDebug(KWAYLAND_SERVER) << "Server buffer sent: fd" << buf->fd();
     for (auto res : clientResources) {
@@ -213,7 +198,7 @@ void RemoteAccessManagerInterface::Private::sendBufferReady(const OutputInterfac
     }
     if (holder.counter == 0) {
         // buffer was not requested by any client
-        emit q->bufferReleased(buf);
+        Q_EMIT q->bufferReleased(buf);
         return;
     }
     // store buffer locally, clients will ask it later
@@ -221,10 +206,7 @@ void RemoteAccessManagerInterface::Private::sendBufferReady(const OutputInterfac
 }
 
 #ifndef K_DOXYGEN
-const struct org_kde_kwin_remote_access_manager_interface RemoteAccessManagerInterface::Private::s_interface = {
-    getBufferCallback,
-    releaseCallback
-};
+const struct org_kde_kwin_remote_access_manager_interface RemoteAccessManagerInterface::Private::s_interface = {getBufferCallback, releaseCallback};
 #endif
 
 void RemoteAccessManagerInterface::Private::getBufferCallback(wl_client *client, wl_resource *resource, uint32_t buffer, int32_t internalBufId)
@@ -252,9 +234,7 @@ void RemoteAccessManagerInterface::Private::getBufferCallback(wl_client *client,
             // all relevant buffers are already unreferenced
             return;
         }
-        qCDebug(KWAYLAND_SERVER) << "Remote buffer returned, client" << wl_resource_get_id(resource)
-                                                     << ", id" << rbuf->id()
-                                                     << ", fd" << bh.buf->fd();
+        qCDebug(KWAYLAND_SERVER) << "Remote buffer returned, client" << wl_resource_get_id(resource) << ", id" << rbuf->id() << ", fd" << bh.buf->fd();
         if (p->unref(bh)) {
             p->sentBuffers.remove(bh.buf->fd());
         }
@@ -276,7 +256,7 @@ bool RemoteAccessManagerInterface::Private::unref(BufferHolder &bh)
     if (!bh.counter) {
         // no more clients using this buffer
         qCDebug(KWAYLAND_SERVER) << "Buffer released, fd" << bh.buf->fd();
-        emit q->bufferReleased(bh.buf);
+        Q_EMIT q->bufferReleased(bh.buf);
         return true;
     }
 
@@ -334,7 +314,7 @@ class RemoteBufferInterface::Private : public Resource::Private
 {
 public:
     Private(RemoteAccessManagerInterface *ram, RemoteBufferInterface *q, wl_resource *pResource, const BufferHandle *buf);
-    ~Private();
+    ~Private() override;
 
     void passFd();
 
@@ -345,13 +325,12 @@ private:
 };
 
 #ifndef K_DOXYGEN
-const struct org_kde_kwin_remote_buffer_interface RemoteBufferInterface::Private::s_interface = {
-    resourceDestroyedCallback
-};
+const struct org_kde_kwin_remote_buffer_interface RemoteBufferInterface::Private::s_interface = {resourceDestroyedCallback};
 #endif
 
 RemoteBufferInterface::Private::Private(RemoteAccessManagerInterface *ram, RemoteBufferInterface *q, wl_resource *pResource, const BufferHandle *buf)
-    : Resource::Private(q, ram, pResource, &org_kde_kwin_remote_buffer_interface, &s_interface), wrapped(buf)
+    : Resource::Private(q, ram, pResource, &org_kde_kwin_remote_buffer_interface, &s_interface)
+    , wrapped(buf)
 {
 }
 
@@ -361,8 +340,7 @@ RemoteBufferInterface::Private::~Private()
 
 void RemoteBufferInterface::Private::passFd()
 {
-    org_kde_kwin_remote_buffer_send_gbm_handle(resource, wrapped->fd(),
-            wrapped->width(), wrapped->height(), wrapped->stride(), wrapped->format());
+    org_kde_kwin_remote_buffer_send_gbm_handle(resource, wrapped->fd(), wrapped->width(), wrapped->height(), wrapped->stride(), wrapped->format());
 }
 
 RemoteBufferInterface::RemoteBufferInterface(RemoteAccessManagerInterface *ram, wl_resource *pResource, const BufferHandle *buf)
@@ -372,10 +350,9 @@ RemoteBufferInterface::RemoteBufferInterface(RemoteAccessManagerInterface *ram,
 
 RemoteBufferInterface::Private *RemoteBufferInterface::d_func() const
 {
-    return reinterpret_cast<Private*>(d.data());
+    return reinterpret_cast<Private *>(d.data());
 }
 
-
 void RemoteBufferInterface::passFd()
 {
     d_func()->passFd();
@@ -383,3 +360,6 @@ void RemoteBufferInterface::passFd()
 
 }
 }
+
+#include "moc_remote_access_interface.cpp"
+#include "moc_remote_access_interface_p.cpp"
